@@ -15,6 +15,8 @@ from django.utils.translation import ugettext_lazy as _
 from sentry.conf import settings
 from sentry.plugins import register
 from sentry.plugins.bases.notify import NotificationPlugin, NotificationConfigurationForm
+from sentry.utils.cache import cache
+
 import re
 
 from pynliner import Pynliner
@@ -56,11 +58,11 @@ class MailProcessor(NotificationPlugin):
     version = sentry.VERSION
     author = "Sentry Team"
     author_url = "https://github.com/getsentry/sentry"
-
+    project_default_enabled = True
     project_conf_form = MailConfigurationForm
 
     def __init__(self, min_level=NOTSET, include_loggers=NOTSET, exclude_loggers=NOTSET,
-                 send_to=None, send_to_members=NOTSET, send_to_admins=NOTSET, *args, **kwargs):
+                 send_to=None, send_to_members=NOTSET, *args, **kwargs):
 
         super(MailProcessor, self).__init__(*args, **kwargs)
 
@@ -72,15 +74,12 @@ class MailProcessor(NotificationPlugin):
             exclude_loggers = settings.MAIL_EXCLUDE_LOGGERS
         if send_to_members is NOTSET:
             send_to_members = True
-        if send_to_admins is NOTSET:
-            send_to_admins = False
 
         self.min_level = min_level
         self.include_loggers = include_loggers
         self.exclude_loggers = exclude_loggers
         self.send_to = send_to
         self.send_to_members = send_to_members
-        self.send_to_admins = send_to_admins
         self.subject_prefix = settings.EMAIL_SUBJECT_PREFIX
 
     def _send_mail(self, subject, body, html_body=None, project=None, fail_silently=False, headers=None):
@@ -106,14 +105,41 @@ class MailProcessor(NotificationPlugin):
         )
 
     def get_send_to(self, project=None):
-        send_to_list = self.get_option('send_to', project) or []
+        """
+        Returns a list of email addresses for the users that should be notified of alerts.
 
-        if isinstance(send_to_list, basestring):
-            send_to_list = [s.strip() for s in send_to_list.split(',')]
+        The logic for this is a bit complicated, but it does the following:
 
-        send_to_list.extend(super(MailProcessor, self).get_send_to(project))
+        - Includes members if ``send_to_members`` is enabled **and** the user has not disabled alerts
+          for this project
 
-        return filter(bool, set(send_to_list))
+        The results of this call can be fairly expensive to calculate, so the send_to list gets cached
+        for 60 seconds.
+        """
+        if project:
+            project_id = project.pk
+        else:
+            project_id = ''
+        conf_key = self.get_conf_key()
+        cache_key = '%s:send_to:%s' % (conf_key, project_id)
+
+        send_to_list = cache.get(cache_key)
+        if send_to_list is None:
+            send_to_list = self.get_option('send_to', project) or []
+
+            if isinstance(send_to_list, basestring):
+                send_to_list = [s.strip() for s in send_to_list.split(',')]
+
+            send_to_list = set(filter(bool, send_to_list))
+
+            send_to_members = self.get_option('send_to_members', project)
+            if send_to_members and project and project.team:
+                member_set = self.get_sendable_users(project)
+                send_to_list |= set(self.get_emails_for_users(member_set))
+
+            cache.set(cache_key, send_to_list, 60)  # 1 minute cache
+
+        return send_to_list
 
     def notify_users(self, group, event, fail_silently=False):
         project = group.project
@@ -161,7 +187,7 @@ class MailProcessor(NotificationPlugin):
     def get_option(self, key, *args, **kwargs):
         value = super(MailProcessor, self).get_option(key, *args, **kwargs)
         if value is None and key in ('min_level', 'include_loggers', 'exclude_loggers',
-                                     'send_to_members', 'send_to_admins', 'send_to',
+                                     'send_to_members', 'send_to',
                                      'subject_prefix'):
             value = getattr(self, key)
         return value
