@@ -18,12 +18,13 @@ class ServersPlugin(TagPlugin):
     Automatically adds the 'server_name' tag from events.
     """
     slug = 'servers'
-    title = _('Servers')
+    title = _('Auto Tag: Servers')
     version = sentry.VERSION
     author = "Sentry Team"
     author_url = "https://github.com/getsentry/sentry"
     tag = 'server_name'
     tag_label = _('Server Name')
+    project_default_enabled = True
 
     def get_tag_values(self, event):
         if not event.server_name:
