@@ -5,28 +5,22 @@ sentry.utils.auth
 :copyright: (c) 2010-2012 by the Sentry Team, see AUTHORS for more details.
 :license: BSD, see LICENSE for more details.
 """
-import hashlib
-import hmac
 from django.conf import settings as dj_settings
 from django.contrib.auth.models import User
 from django.contrib.auth.backends import ModelBackend
 from sentry.conf import settings
 
 
-def get_signature(message, timestamp, key=None):
-    if not key:
-        key = settings.KEY
-    return hmac.new(str(key), '%s %s' % (timestamp, message), hashlib.sha1).hexdigest()
-
-
-def get_auth_header(signature, timestamp, client, api_key=None):
+def get_auth_header(client, api_key=None, secret_key=None):
     header = [
-        ('sentry_timestamp', timestamp),
-        ('sentry_signature', signature),
         ('sentry_client', client),
+        ('sentry_version', '3'),
     ]
+
     if api_key:
         header.append(('sentry_key', api_key))
+    if secret_key:
+        header.append(('sentry_secret', secret_key))
 
     return 'Sentry %s' % ', '.join('%s=%s' % (k, v) for k, v in header)
 
@@ -56,7 +50,7 @@ class EmailAuthBackend(ModelBackend):
             if '@' in username:
                 try:
                     user = User.objects.get(email__iexact=username)
-                except user.DoesNotExist:
+                except User.DoesNotExist:
                     return None
             else:
                 return None
